==> personal-page-ui-0.1.4.tgz: package/src/components/info-block/InfoBlock.tsx <==
import KeyboardArrowDownIcon from '@mui/icons-material/KeyboardArrowDown';
import KeyboardArrowUpIcon from '@mui/icons-material/KeyboardArrowUp';
import { Collapse, useTheme } from '@mui/material';
import IconButton from '@mui/material/IconButton';
import React, { ReactNode, useState } from 'react';
import { WithChildren } from './../../helpers/withChildren';
import s from './InfoBlock.module.css';

type Props = WithChildren<{
  title: string;
  titleIcon?: ReactNode;
  tooltip?: ReactNode;
  expandable?: boolean;
  className?: string;
  isOpenProp?: boolean;
  onClickHandler?: () => void;
  noBorder?: boolean;
  disabled?: boolean;
}>;

export const UiInfoBlock: React.FC<Props> = ({
  title,
  titleIcon,
  tooltip,
  expandable,
  children,
  className,
  isOpenProp,
  onClickHandler,
  noBorder,
  disabled,
}) => {
  const theme = useTheme();
  const isDarkTheme = theme.palette.mode === 'dark';

  const [isOpen, setIsOpen] = useState(false);
  const toggleBlockHandler = () => {
    expandable && setIsOpen(!isOpen);
  };
  return (
    <div className={className}>
      <div
        onClick={onClickHandler ? onClickHandler : toggleBlockHandler}
        className={`${s.header} ${isDarkTheme ? s.headerDark : ''}`}
        style={{
          cursor: expandable ? (disabled ? 'not-allowed' : 'pointer') : 'auto',
        }}
      >
        <div className={s.tooltipBox}>
          {tooltip && <p className={s.tooltip}>{tooltip}</p>}
          {titleIcon}
          <p>{title}</p>
        </div>
        {expandable && (
          <IconButton
            aria-label="expand row"
            size="small"
            sx={{ cursor: disabled ? 'not-allowed' : 'pointer' }}
          >
            {isOpen ? <KeyboardArrowUpIcon /> : <KeyboardArrowDownIcon />}
          </IconButton>
        )}
      </div>

      {/* Block content  */}
      <Collapse
        in={
          expandable ? (isOpenProp !== undefined ? isOpenProp : isOpen) : true
        }
        timeout="auto"
        unmountOnExit
        sx={{ width: '100%' }}
      >
        <div
          className={`${s.content} ${isDarkTheme ? s.contentDark : ''}}`}
          style={{ border: noBorder ? 'none' : '' }}
        >
          {children}
        </div>
      </Collapse>
    </div>
  );
};

==> personal-page-ui-0.1.9.tgz: package/src/components/info-block/InfoBlock.tsx <==
import KeyboardArrowDownIcon from '@mui/icons-material/KeyboardArrowDown';
import KeyboardArrowUpIcon from '@mui/icons-material/KeyboardArrowUp';
import { Collapse, useTheme } from '@mui/material';
import IconButton from '@mui/material/IconButton';
import clsx from 'clsx';
import React, { ReactNode, useState } from 'react';
import { WithChildren } from './../../helpers/withChildren';
// import s from './InfoBlock.module.css';

type Props = WithChildren<{
  title: string;
  titleIcon?: ReactNode;
  tooltip?: ReactNode;
  expandable?: boolean;
  className?: string;
  isOpenProp?: boolean;
  onClickHandler?: () => void;
  noBorder?: boolean;
  disabled?: boolean;
}>;

export const UiInfoBlock: React.FC<Props> = ({
  title,
  titleIcon,
  tooltip,
  expandable,
  children,
  className,
  isOpenProp,
  onClickHandler,
  noBorder,
  disabled,
}) => {
  const theme = useTheme();
  const isDarkTheme = theme.palette.mode === 'dark';
  console.log({ onClickHandler });
  const [isOpen, setIsOpen] = useState(false);
  const toggleBlockHandler = () => {
    console.log('asdf');
    expandable && setIsOpen(!isOpen);
  };
  return (
    <div className={clsx(className, isDarkTheme && 'dark')}>
      <div
        onClick={onClickHandler ? onClickHandler : toggleBlockHandler}
        className={
          'bg-[#e5e5e5] dark:bg-[#263648] flex items-center justify-between py-[6px] px-[24px] w-full text-bold rounded-t-[4px] h-9'
        }
        style={{
          cursor: expandable ? (disabled ? 'not-allowed' : 'pointer') : 'auto',
        }}
      >
        <div className={'flex items-center'}>
          {tooltip && <p className={'mt-[3px] mr-4'}>{tooltip}</p>}
          {titleIcon}
          <p>{title}</p>
        </div>
        {expandable && (
          <IconButton
            aria-label="expand row"
            size="small"
            sx={{ cursor: disabled ? 'not-allowed' : 'pointer' }}
          >
            {isOpen ? <KeyboardArrowUpIcon /> : <KeyboardArrowDownIcon />}
          </IconButton>
        )}
      </div>

      {/* Block content  */}
      <Collapse
        in={
          expandable ? (isOpenProp !== undefined ? isOpenProp : isOpen) : true
        }
        timeout="auto"
        unmountOnExit
        sx={{ width: '100%' }}
      >
        <div
          className={clsx(
            !noBorder && 'border',
            'bg-white dark:bg-[#222f40] border-[#e5e5e5] dark:border-[#263648] rounded-b-[4px]'
          )}
        >
          {children}
        </div>
      </Collapse>
    </div>
  );
};
